pub struct LedgerStorage { /* private fields */ }This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Implementations
Sourceimpl LedgerStorage
impl LedgerStorage
pub async fn new( read_only: bool, timeout: Option<Duration>, credential_path: Option<String>, ) -> Result<Self>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn new_for_emulator( instance_name: &str, app_profile_id: &str, endpoint: &str, timeout: Option<Duration>, ) -> Result<Self>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn new_with_config(config: LedgerStorageConfig) -> Result<Self>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn new_with_stringified_credential(credential: String) -> Result<Self>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Sourcepub async fn get_first_available_block(&self) -> Result<Option<Slot>>
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn get_first_available_block(&self) -> Result<Option<Slot>>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Return the available slot that contains a block
Sourcepub async fn get_confirmed_blocks(
&self,
start_slot: Slot,
limit: usize,
) -> Result<Vec<Slot>>
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn get_confirmed_blocks( &self, start_slot: Slot, limit: usize, ) -> Result<Vec<Slot>>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fetch the next slots after the provided slot that contains a block
start_slot: slot to start the search from (inclusive) limit: stop after this many slots have been found
pub async fn get_confirmed_blocks_with_data<'a>( &self, slots: &'a [Slot], ) -> Result<impl Iterator<Item = (Slot, ConfirmedBlock)> + 'a>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Sourcepub async fn get_confirmed_block(&self, slot: Slot) -> Result<ConfirmedBlock>
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn get_confirmed_block(&self, slot: Slot) -> Result<ConfirmedBlock>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fetch the confirmed block from the desired slot
Sourcepub async fn confirmed_block_exists(&self, slot: Slot) -> Result<bool>
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn confirmed_block_exists(&self, slot: Slot) -> Result<bool>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Does the confirmed block exist in the Bigtable
Sourcepub async fn get_entries(
&self,
slot: Slot,
) -> Result<impl Iterator<Item = EntrySummary>>
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn get_entries( &self, slot: Slot, ) -> Result<impl Iterator<Item = EntrySummary>>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fetches a vector of block entries via a multirow fetch
pub async fn get_signature_status( &self, signature: &Signature, ) -> Result<TransactionStatus>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn get_confirmed_transactions( &self, signatures: &[Signature], ) -> Result<Vec<ConfirmedTransactionWithStatusMeta>>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Sourcepub async fn get_confirmed_transaction(
&self,
signature: &Signature,
) -> Result<Option<ConfirmedTransactionWithStatusMeta>>
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn get_confirmed_transaction( &self, signature: &Signature, ) -> Result<Option<ConfirmedTransactionWithStatusMeta>>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fetch a confirmed transaction
Sourcepub async fn get_confirmed_signatures_for_address(
&self,
address: &Pubkey,
before_signature: Option<&Signature>,
until_signature: Option<&Signature>,
limit: usize,
) -> Result<Vec<(ConfirmedTransactionStatusWithSignature, u32)>>
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn get_confirmed_signatures_for_address( &self, address: &Pubkey, before_signature: Option<&Signature>, until_signature: Option<&Signature>, limit: usize, ) -> Result<Vec<(ConfirmedTransactionStatusWithSignature, u32)>>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Get confirmed signatures for the provided address, in descending ledger order
address: address to search for before_signature: start with the first signature older than this one until_signature: end with the last signature more recent than this one limit: stop after this many signatures; if limit==0, all records in the table will be read
Sourcepub async fn upload_confirmed_block(
&self,
slot: Slot,
confirmed_block: VersionedConfirmedBlock,
) -> Result<()>
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn upload_confirmed_block( &self, slot: Slot, confirmed_block: VersionedConfirmedBlock, ) -> Result<()>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Upload a new confirmed block and associated meta data.
pub async fn upload_confirmed_block_with_entries( &self, slot: Slot, confirmed_block: VersionedConfirmedBlockWithEntries, ) -> Result<()>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub async fn delete_confirmed_block( &self, slot: Slot, dry_run: bool, ) -> Result<()>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.